@@ -14,6 +14,12 @@ impl<'a> ContentType<'a> {
     }
 }
 
+impl<'a> AddAsHeader for ContentType<'a> {
+    fn add_as_header(&self, builder: Builder) -> Builder {
+        builder.header(http::header::CONTENT_TYPE, self.0)
+    }
+}
+
 impl<'a, S> From<S> for ContentType<'a>
 where
     S: Into<&'a str>,
@@ -22,21 +28,3 @@ where
         Self(s.into())
     }
 }
-
-impl<'a> AddAsHeader for ContentType<'a> {
-    fn add_as_header(&self, builder: Builder) -> Builder {
-        builder.header(http::header::CONTENT_TYPE, self.0)
-    }
-
-    fn add_as_header2(
-        &self,
-        request: &mut crate::Request,
-    ) -> Result<(), crate::errors::HttpHeaderError> {
-        request.headers_mut().append(
-            http::header::CONTENT_TYPE,
-            http::HeaderValue::from_str(self.0)?,
-        );
-
-        Ok(())
-    }
-}
